summaryrefslogtreecommitdiffstats
path: root/chrome/browser/sync/engine/download_updates_command.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/sync/engine/download_updates_command.h')
-rw-r--r--chrome/browser/sync/engine/download_updates_command.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/chrome/browser/sync/engine/download_updates_command.h b/chrome/browser/sync/engine/download_updates_command.h
index efd5468..6169bb7 100644
--- a/chrome/browser/sync/engine/download_updates_command.h
+++ b/chrome/browser/sync/engine/download_updates_command.h
@@ -7,16 +7,17 @@
#include "base/basictypes.h"
#include "chrome/browser/sync/engine/syncer_command.h"
-#include "chrome/browser/sync/engine/syncer_session.h"
namespace browser_sync {
// Downloads updates from the server and places them in the SyncerSession.
class DownloadUpdatesCommand : public SyncerCommand {
public:
DownloadUpdatesCommand();
virtual ~DownloadUpdatesCommand();
- virtual void ExecuteImpl(SyncerSession* session);
+
+ // SyncerCommand implementation.
+ virtual void ExecuteImpl(sessions::SyncSession* session);
private:
DISALLOW_COPY_AND_ASSIGN(DownloadUpdatesCommand);
@@ -7,16 +7,17 @@
namespace browser_sync {
-// Downloads updates from the server and places them in the SyncerSession.
+// Downloads updates from the server and places them in the SyncSession.
class DownloadUpdatesCommand : public SyncerCommand {
public: